pub struct CcActionInput {
pub path: PathBuf,
pub digest: CacheDigest,
}Expand description
One file input paired with the digest used in the action key.
Fields
path: PathBufAbsolute host path used to read and verify the input, or an include-manifest pseudo-path.
digest: CacheDigestDigest of the input contents, or of the directory’s name manifest.