pub fn environment_inputs<F>(
lookup: F,
sysroot: Option<&Path>,
) -> Result<BTreeMap<String, Option<String>>, CcBypassReason>Expand description
Read the modeled environment, rejecting variables that change the compile in a way the argv model cannot see.